@@ -60,12 +60,13 @@ class Connection(AdomdConnection):
             """This is a bit garbage will need to refactor later but fixing issue with System.Decimal conversion"""
             Results.append(
                 [
-                    Query.GetValue(index)
-                    if Query.GetDataTypeName((index)) not in ("Object", "Decimal")
-                    else Query.GetValue(index).ToDouble(Query.GetValue(index))
+                    Query.GetValue(index).ToDouble(Query.GetValue(index))
+                    if Query.GetDataTypeName((index)) in ("Decimal")
+                    else Query.GetValue(index)
                     for index in range(0, len(Column_Headers))
                 ]
             )
+
         Query.Close()
         logger.debug("Data retrieved... reading...")
         df = pd.DataFrame(Results, columns=[value for _, value in Column_Headers])
